@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import re
 from pathlib import Path
+from typing import Optional
 from xml.etree.ElementTree import Element
 
 import requests
@@ -38,8 +39,8 @@ class TEIParser:
         self,
         *,
         environment_manager: colrev.env.environment_manager.EnvironmentManager,
-        pdf_path: Path = None,
-        tei_path: Path = None,
+        pdf_path: Optional[Path] = None,
+        tei_path: Optional[Path] = None,
     ):
         """Creates a TEI file
         modes of operation:
@@ -315,7 +316,6 @@ class TEIParser:
         return author_dict
 
     def __get_author_name_from_node(self, *, author_node: Element) -> str:
-
         authorname = ""
 
         author_pers_node = author_node.find(self.ns["tei"] + "persName")
@@ -360,7 +360,6 @@ class TEIParser:
                     for author_node in analytic_node.iterfind(
                         self.ns["tei"] + "author"
                     ):
-
                         authorname = self.__get_author_name_from_node(
                             author_node=author_node
                         )
@@ -408,6 +407,7 @@ class TEIParser:
             )
             html_str = etree.tostring(abstract_node).decode("utf-8")
             abstract_text = cleanhtml(html_str)
+        abstract_text = abstract_text.lstrip().rstrip()
         return abstract_text
 
     def get_metadata(self) -> dict:
@@ -498,7 +498,6 @@ class TEIParser:
 
         if authors_node is not None:
             for author_node in authors_node.iterfind(self.ns["tei"] + "author"):
-
                 authorname = self.__get_author_name_from_node(author_node=author_node)
 
                 if authorname not in [", ", ""]:
@@ -675,8 +674,19 @@ class TEIParser:
                         entrytype = "book"
         return entrytype
 
-    def get_bibliography(self) -> list:
+    def __get_tei_id_count(self, *, tei_id: str) -> int:
+        count = 0
+
+        for reference in self.root.iter(self.ns["tei"] + "ref"):
+            if "target" in reference.keys():
+                if reference.get("target") == f"#{tei_id}":
+                    count += 1
+
+        return count
+
+    def get_bibliography(self, *, min_intext_citations: int = 0) -> list:
         """Get the bibliography (references section) as a list of record dicts"""
+        # Note : could also allow top-10 % of most frequent in-text citations
 
         bibliographies = self.root.iter(self.ns["tei"] + "listBibl")
         tei_bib_db = []
@@ -687,6 +697,14 @@ class TEIParser:
                     tei_id = self.__get_reference_bibliography_tei_id(
                         reference=reference
                     )
+
+                    if min_intext_citations > 0:
+                        if (
+                            self.__get_tei_id_count(tei_id=tei_id)
+                            < min_intext_citations
+                        ):
+                            continue
+
                     if "article" == entrytype:
                         ref_rec = {
                             "ID": tei_id,
@@ -778,7 +796,7 @@ class TEIParser:
                 section_citations[section_name.lower()] = citations
         return section_citations
 
-    def mark_references(self, *, records: list):  # type: ignore
+    def mark_references(self, *, records: dict):  # type: ignore
         """Mark references with the additional record ID"""
 
         tei_records = self.get_bibliography()
@@ -788,8 +806,8 @@ class TEIParser:
 
             max_sim = 0.9
             max_sim_record = {}
-            for local_record_dict in records:
-                if local_record_dict["status"] not in [
+            for local_record_dict in records.values():
+                if local_record_dict["colrev_status"] not in [
                     colrev.record.RecordState.rev_included,
                     colrev.record.RecordState.rev_synthesized,
                 ]:
