@@ -22,6 +22,7 @@ class ScopingReview(JsonSchemaMixin):
     """Scoping review"""
 
     settings_class = colrev.env.package_manager.DefaultSettings
+    ci_supported: bool = True
 
     def __init__(
         self, *, operation: colrev.operation.CheckOperation, settings: dict
@@ -37,17 +38,16 @@ class ScopingReview(JsonSchemaMixin):
         """Initialize a scoping review"""
 
         settings.data.data_package_endpoints = [
-            {"endpoint": "colrev_built_in.prisma", "version": "1.0"},
+            {"endpoint": "colrev.prisma", "version": "1.0"},
             {
-                "endpoint": "colrev_built_in.obsidian",
+                "endpoint": "colrev.obsidian",
                 "version": "0.1",
                 "config": {},
             },
             {
-                "endpoint": "colrev_built_in.manuscript",
+                "endpoint": "colrev.paper_md",
                 "version": "1.0",
                 "word_template": "APA-7.docx",
-                "csl_style": "apa.csl",
             },
         ]
         return settings
