@@ -22,6 +22,7 @@ class TheoreticalReview(JsonSchemaMixin):
     """Theoretical review"""
 
     settings_class = colrev.env.package_manager.DefaultSettings
+    ci_supported: bool = True
 
     def __init__(
         self, *, operation: colrev.operation.CheckOperation, settings: dict
@@ -38,15 +39,14 @@ class TheoreticalReview(JsonSchemaMixin):
 
         settings.data.data_package_endpoints = [
             {
-                "endpoint": "colrev_built_in.obsidian",
+                "endpoint": "colrev.obsidian",
                 "version": "0.1",
                 "config": {},
             },
             {
-                "endpoint": "colrev_built_in.manuscript",
+                "endpoint": "colrev.paper_md",
                 "version": "1.0",
                 "word_template": "APA-7.docx",
-                "csl_style": "apa.csl",
             },
         ]
         return settings
