@@ -33,7 +33,10 @@ class ABIInformProQuestSearchSource(JsonSchemaMixin):
     ci_supported: bool = False
     heuristic_status = colrev.env.package_manager.SearchSourceHeuristicStatus.supported
     short_name = "ABI/INFORM (ProQuest)"
-    link = "https://about.proquest.com/en/products-services/abi_inform_complete/"
+    link = (
+        "https://github.com/CoLRev-Environment/colrev/blob/main/colrev/"
+        + "ops/built_in/search_sources/abi_inform_proquest.md"
+    )
 
     def __init__(
         self, *, source_operation: colrev.operation.CheckOperation, settings: dict
