@@ -35,7 +35,10 @@ class ACMDigitalLibrarySearchSource(JsonSchemaMixin):
     ci_supported: bool = False
     heuristic_status = colrev.env.package_manager.SearchSourceHeuristicStatus.supported
     short_name = "ACM Digital Library"
-    link = "https://dl.acm.org/"
+    link = (
+        "https://github.com/CoLRev-Environment/colrev/blob/main/colrev/"
+        + "ops/built_in/search_sources/acm_digital_library.md"
+    )
 
     def __init__(
         self, *, source_operation: colrev.operation.CheckOperation, settings: dict
