@@ -39,7 +39,10 @@ class AISeLibrarySearchSource(JsonSchemaMixin):
     ci_supported: bool = True
     heuristic_status = colrev.env.package_manager.SearchSourceHeuristicStatus.supported
     short_name = "AIS eLibrary"
-    link = "https://aisel.aisnet.org/"
+    link = (
+        "https://github.com/CoLRev-Environment/colrev/blob/main/"
+        + "colrev/ops/built_in/search_sources/aisel.md"
+    )
 
     def __init__(
         self, *, source_operation: colrev.operation.CheckOperation, settings: dict
@@ -78,6 +81,8 @@ class AISeLibrarySearchSource(JsonSchemaMixin):
         # pylint: disable=too-many-locals
         # pylint: disable=too-many-statements
 
+        query = query.lstrip("colrev.ais_library:").rstrip('"').lstrip('"')
+
         host = urlparse(query).hostname
 
         if host and host.endswith("aisel.aisnet.org"):
