@@ -49,7 +49,10 @@ class DBLPSearchSource(JsonSchemaMixin):
     ci_supported: bool = True
     heuristic_status = colrev.env.package_manager.SearchSourceHeuristicStatus.supported
     short_name = "DBLP"
-    link = "https://dblp.org/"
+    link = (
+        "https://github.com/CoLRev-Environment/colrev/blob/main/"
+        + "colrev/ops/built_in/search_sources/dblp.md"
+    )
     __dblp_md_filename = Path("data/search/md_dblp.bib")
 
     @dataclass
