@@ -39,7 +39,10 @@ class OpenCitationsSearchSource(JsonSchemaMixin):
     ci_supported: bool = True
     heuristic_status = colrev.env.package_manager.SearchSourceHeuristicStatus.supported
     short_name = "OpenCitations forward search"
-    link = "https://opencitations.net/"
+    link = (
+        "https://github.com/CoLRev-Environment/colrev/blob/main/"
+        + "colrev/ops/built_in/search_sources/open_citations_forward_search.md"
+    )
 
     def __init__(
         self, *, source_operation: colrev.operation.CheckOperation, settings: dict
