@@ -42,7 +42,10 @@ class PDFSearchSource(JsonSchemaMixin):
     ci_supported: bool = False
     heuristic_status = colrev.env.package_manager.SearchSourceHeuristicStatus.supported
     short_name = "PDF directory"
-    link = "https://github.com/kermitt2/grobid"
+    link = (
+        "https://github.com/CoLRev-Environment/colrev/blob/main/"
+        + "colrev/ops/built_in/search_sources/pdfs_dir.md"
+    )
 
     __doi_regex = re.compile(r"10\.\d{4,9}/[-._;/:A-Za-z0-9]*")
 
@@ -599,7 +602,7 @@ class PDFSearchSource(JsonSchemaMixin):
                         )
                         res = re.findall(self.__doi_regex, record.data["text_from_pdf"])
                         if res:
-                            record["doi"] = res[0].upper()
+                            record.data["doi"] = res[0].upper()
                         del record.data["text_from_pdf"]
 
                 elif search_operation.review_manager.force_mode:
