@@ -9,6 +9,7 @@ from glob import glob
 from multiprocessing.pool import ThreadPool as Pool
 from pathlib import Path
 
+import colrev.exceptions as colrev_exceptions
 import colrev.operation
 import colrev.record
 import colrev.ui_cli.cli_colors as colors
@@ -27,7 +28,6 @@ class PDFGet(colrev.operation.Operation):
         review_manager: colrev.review_manager.ReviewManager,
         notify_state_transition_operation: bool = True,
     ) -> None:
-
         super().__init__(
             review_manager=review_manager,
             operations_type=colrev.operation.OperationsType.pdf_get,
@@ -36,13 +36,13 @@ class PDFGet(colrev.operation.Operation):
 
         self.package_manager = self.review_manager.get_package_manager()
 
-        self.review_manager.pdf_dir.mkdir(exist_ok=True)
+        self.review_manager.pdf_dir.mkdir(exist_ok=True, parents=True)
 
         self.filepath_directory_pattern = ""
         pdf_endpoints = [
             s
             for s in self.review_manager.settings.sources
-            if s.endpoint == "colrev_built_in.pdfs_dir"
+            if s.endpoint == "colrev.pdfs_dir"
         ]
         if pdf_endpoints:
             self.filepath_directory_pattern = (
@@ -84,7 +84,11 @@ class PDFGet(colrev.operation.Operation):
         ):
             record.update_field(key="file", value=str(pdf_filepath), source="link_pdf")
             self.import_file(record=record)
-            record.set_status(target_state=colrev.record.RecordState.pdf_imported)
+            if (
+                colrev.record.RecordState.rev_prescreen_included
+                == record.data["colrev_status"]
+            ):
+                record.set_status(target_state=colrev.record.RecordState.pdf_imported)
 
         return record
 
@@ -158,12 +162,17 @@ class PDFGet(colrev.operation.Operation):
         for (
             pdf_get_package_endpoint
         ) in self.review_manager.settings.pdf_get.pdf_get_package_endpoints:
-
             endpoint_dict = self.package_manager.load_packages(
                 package_type=colrev.env.package_manager.PackageEndpointType.pdf_get,
                 selected_packages=[pdf_get_package_endpoint],
                 operation=self,
+                only_ci_supported=self.review_manager.in_ci_environment(),
             )
+            if pdf_get_package_endpoint["endpoint"] not in endpoint_dict:
+                self.review_manager.logger.info(
+                    f'Skip {pdf_get_package_endpoint["endpoint"]} (not available)'
+                )
+                continue
 
             endpoint = endpoint_dict[pdf_get_package_endpoint["endpoint"]]
             endpoint.get_pdf(self, record)  # type: ignore
@@ -173,21 +182,35 @@ class PDFGet(colrev.operation.Operation):
                     f"{endpoint.settings.endpoint}"  # type: ignore
                     f'({record_dict["ID"]}): retrieved .../{Path(record_dict["file"]).name}'
                 )
-                record.data.update(colrev_status=colrev.record.RecordState.pdf_imported)
-                self.review_manager.logger.info(
-                    f" {colors.GREEN}{record.data['ID']}".ljust(46)
-                    + f"rev_prescreen_included → pdf_imported{colors.END}"
-                )
+                if (
+                    colrev.record.RecordState.rev_prescreen_included
+                    == record.data["colrev_status"]
+                ):
+                    record.data.update(
+                        colrev_status=colrev.record.RecordState.pdf_imported
+                    )
+                    self.review_manager.logger.info(
+                        f" {colors.GREEN}{record.data['ID']}".ljust(46)
+                        + f"rev_prescreen_included → pdf_imported{colors.END}"
+                    )
                 return record.get_data()
 
-        self.review_manager.logger.info(
-            f" {colors.ORANGE}{record.data['ID']}".ljust(46)
-            + f"rev_prescreen_included → pdf_needs_manual_retrieval{colors.END}"
-        )
+        if self.review_manager.settings.pdf_get.pdf_required_for_screen_and_synthesis:
+            self.review_manager.logger.info(
+                f" {colors.ORANGE}{record.data['ID']}".ljust(46)
+                + f"rev_prescreen_included → pdf_needs_manual_retrieval{colors.END}"
+            )
 
-        record.data.update(
-            colrev_status=colrev.record.RecordState.pdf_needs_manual_retrieval
-        )
+            record.data.update(
+                colrev_status=colrev.record.RecordState.pdf_needs_manual_retrieval
+            )
+        else:
+            self.review_manager.logger.info(
+                f" {colors.ORANGE}{record.data['ID']}".ljust(46)
+                + f"rev_prescreen_included → pdf_prepared{colors.END}"
+            )
+
+            record.data.update(colrev_status=colrev.record.RecordState.pdf_prepared)
 
         return record.get_data()
 
@@ -202,7 +225,7 @@ class PDFGet(colrev.operation.Operation):
         corresponding_origin: str
         source_records: typing.List[typing.Dict] = []
         for source in self.review_manager.settings.sources:
-            if "colrev_built_in.pdfs_dir" != source.endpoint:
+            if "colrev.pdfs_dir" != source.endpoint:
                 continue
 
             if not source.filename.is_file():
@@ -322,7 +345,6 @@ class PDFGet(colrev.operation.Operation):
             msg = f"Check unlinked PDF: {file.relative_to(self.review_manager.path)}"
             self.review_manager.logger.info(msg)
             if file.stem not in records.keys():
-
                 tei = self.review_manager.get_tei(pdf_path=file)
                 pdf_record = tei.get_metadata()
 
@@ -354,9 +376,13 @@ class PDFGet(colrev.operation.Operation):
                             source="linking-available-files",
                         )
                         self.import_file(record=record)
-                        record.set_status(
-                            target_state=colrev.record.RecordState.pdf_imported
-                        )
+                        if (
+                            colrev.record.RecordState.rev_prescreen_included
+                            == record.data["colrev_status"]
+                        ):
+                            record.set_status(
+                                target_state=colrev.record.RecordState.pdf_imported
+                            )
 
                         self.review_manager.report_logger.info(
                             "linked unlinked pdf:" f" {file.name}"
@@ -440,7 +466,11 @@ class PDFGet(colrev.operation.Operation):
 
             record["file"] = str(new_filename)
             self.review_manager.logger.info(f"rename {file.name} > {new_filename}")
-            record["colrev_status"] = colrev.record.RecordState.pdf_imported
+            if (
+                colrev.record.RecordState.rev_prescreen_included
+                == record["colrev_status"]
+            ):
+                record["colrev_status"] = colrev.record.RecordState.pdf_imported
 
         self.review_manager.dataset.save_records_dict(records=records)
 
@@ -481,7 +511,6 @@ class PDFGet(colrev.operation.Operation):
         return pdf_get_data
 
     def _print_stats(self, *, retrieved_record_list: list) -> None:
-
         self.retrieved = len([r for r in retrieved_record_list if "file" in r])
 
         self.not_retrieved = self.to_retrieve - self.retrieved
@@ -516,7 +545,6 @@ class PDFGet(colrev.operation.Operation):
         self.review_manager.logger.info(not_retrieved_string)
 
     def __set_status_if_file_linked(self, *, records: dict) -> dict:
-
         for record in records.values():
             if record["colrev_status"] in [
                 colrev.record.RecordState.rev_prescreen_included,
@@ -526,12 +554,19 @@ class PDFGet(colrev.operation.Operation):
                     if any(
                         Path(fpath).is_file() for fpath in record["file"].split(";")
                     ):
-                        record["colrev_status"] = colrev.record.RecordState.pdf_imported
+                        if (
+                            colrev.record.RecordState.rev_prescreen_included
+                            == record["colrev_status"]
+                        ):
+                            record[
+                                "colrev_status"
+                            ] = colrev.record.RecordState.pdf_imported
                     else:
-                        print(
-                            "Warning: record with file field but no existing PDF "
+                        self.review_manager.logger.warning(
+                            "Remove non-existent file link "
                             f'({record["ID"]}: {record["file"]}'
                         )
+                        colrev.record.Record(data=record).remove_field(key="file")
         self.review_manager.dataset.save_records_dict(records=records)
         self.review_manager.dataset.add_record_changes()
 
@@ -558,12 +593,22 @@ class PDFGet(colrev.operation.Operation):
     def main(self) -> None:
         """Get PDFs (main entrypoint)"""
 
+        if self.review_manager.in_ci_environment():
+            raise colrev_exceptions.ServiceNotAvailableException(
+                dep="colrev pdf-prep",
+                detailed_trace="pdf-prep not available in ci environment",
+            )
+
         self.review_manager.logger.info("Get PDFs")
         self.review_manager.logger.info(
             "Get PDFs of prescreen-included records from local and remote sources."
         )
         self.review_manager.logger.info(
-            f"PDFs are stored in the directory {colors.ORANGE}data/pdfs{colors.END}"
+            "PDFs are stored in the directory data/pdfs "
+            f"({colors.ORANGE}colrev pdfs --dir{colors.END})"
+        )
+        self.review_manager.logger.info(
+            "See https://colrev.readthedocs.io/en/latest/manual/pdf_retrieval/pdf_get.html"
         )
 
         records = self.review_manager.dataset.load_records_dict()
