@@ -7,6 +7,7 @@ import time
 from copy import deepcopy
 from pathlib import Path
 from random import randint
+from typing import Optional
 
 import requests
 from pybtex.database.input import bibtex
@@ -26,7 +27,6 @@ class Search(colrev.operation.Operation):
         review_manager: colrev.review_manager.ReviewManager,
         notify_state_transition_operation: bool = True,
     ) -> None:
-
         super().__init__(
             review_manager=review_manager,
             operations_type=colrev.operation.OperationsType.search,
@@ -40,6 +40,9 @@ class Search(colrev.operation.Operation):
 
         file_path_string = file_path_string.replace("+", "_").replace(" ", "_")
 
+        if file_path_string.endswith(suffix):
+            file_path_string = file_path_string.rstrip(suffix)
+            # suffix = ""
         filename = Path(f"data/search/{file_path_string}{suffix}")
         existing_filenames = [x.filename for x in self.sources]
         if filename not in existing_filenames:
@@ -76,11 +79,10 @@ class Search(colrev.operation.Operation):
 
         self.main(selection_str=str(add_source.filename), rerun=False, skip_commit=True)
         self.review_manager.create_commit(
-            msg=f"Add search source {add_source.filename}",
+            msg=f"Add search source {add_source.filename.relative_to(self.review_manager.path)}",
         )
 
     def __remove_forthcoming(self, *, source: colrev.settings.SearchSource) -> None:
-
         with open(source.get_corresponding_bib_file(), encoding="utf8") as bibtex_file:
             records = self.review_manager.dataset.load_records_dict(
                 load_str=bibtex_file.read()
@@ -104,9 +106,8 @@ class Search(colrev.operation.Operation):
             )
 
     def __get_search_sources(
-        self, *, selection_str: str = None
+        self, *, selection_str: Optional[str] = None
     ) -> list[colrev.settings.SearchSource]:
-
         sources_selected = self.sources
         if selection_str:
             if "all" != selection_str:
@@ -128,7 +129,6 @@ class Search(colrev.operation.Operation):
         return sources_selected
 
     def __have_changed(self, *, record_a_orig: dict, record_b_orig: dict) -> bool:
-
         # To ignore changes introduced by saving/loading the feed-records,
         # we parse and load them in the following.
         record_a = deepcopy(record_a_orig)
@@ -185,7 +185,6 @@ class Search(colrev.operation.Operation):
 
         origin = f"{source.get_origin_prefix()}/{record_dict['ID']}"
         for main_record_dict in records.values():
-
             if origin not in main_record_dict["colrev_origin"]:
                 continue
 
@@ -202,10 +201,9 @@ class Search(colrev.operation.Operation):
                 main_record.remove_field(key="warning")
                 changed = True
 
-            if (
-                "forthcoming" == main_record_dict["year"]
-                and "forthcoming" != record_dict["year"]
-            ):
+            if "forthcoming" == main_record_dict.get(
+                "year", ""
+            ) and "forthcoming" != record_dict.get("year", ""):
                 self.review_manager.logger.info(
                     f"{colors.GREEN}Update published forthcoming paper: "
                     f"{record.data['ID']}{colors.END}"
@@ -229,7 +227,6 @@ class Search(colrev.operation.Operation):
             )
 
             for key, value in record_dict.items():
-
                 if (
                     not update_time_variant_fields
                     and key in colrev.record.Record.time_variant_fields
@@ -308,14 +305,33 @@ class Search(colrev.operation.Operation):
         return changed
 
     def main(
-        self, *, selection_str: str = None, rerun: bool, skip_commit: bool = False
+        self,
+        *,
+        selection_str: Optional[str] = None,
+        rerun: bool,
+        skip_commit: bool = False,
     ) -> None:
         """Search for records (main entrypoint)"""
 
+        if selection_str:
+            if Path(selection_str) not in [
+                s.filename for s in self.review_manager.settings.sources
+            ]:
+                raise colrev_exceptions.ParameterError(
+                    parameter="select",
+                    value=selection_str,
+                    options=[
+                        str(s.filename) for s in self.review_manager.settings.sources
+                    ],
+                )
+
         self.review_manager.logger.info("Search")
         self.review_manager.logger.info(
             "Retrieve new records from an API or files (search sources)."
         )
+        self.review_manager.logger.info(
+            "See https://colrev.readthedocs.io/en/latest/manual/metadata_retrieval/search.html"
+        )
 
         # Reload the settings because the search sources may have been updated
         self.review_manager.settings = self.review_manager.load_settings()
@@ -323,13 +339,14 @@ class Search(colrev.operation.Operation):
         package_manager = self.review_manager.get_package_manager()
 
         for source in self.__get_search_sources(selection_str=selection_str):
-
             endpoint_dict = package_manager.load_packages(
                 package_type=colrev.env.package_manager.PackageEndpointType.search_source,
                 selected_packages=[source.get_dict()],
                 operation=self,
+                only_ci_supported=self.review_manager.in_ci_environment(),
             )
-
+            if source.endpoint.lower() not in endpoint_dict:
+                continue
             endpoint = endpoint_dict[source.endpoint.lower()]
             endpoint.validate_source(search_operation=self, source=source)  # type: ignore
 
@@ -341,7 +358,7 @@ class Search(colrev.operation.Operation):
             if not self.review_manager.high_level_operation:
                 print()
             self.review_manager.logger.info(
-                f"Search operation [{source.endpoint} > data/search/{source.filename.name}]"
+                f"search [{source.endpoint} > data/search/{source.filename.name}]"
             )
 
             try:
@@ -355,10 +372,15 @@ class Search(colrev.operation.Operation):
                 if not self.review_manager.settings.search.retrieve_forthcoming:
                     self.__remove_forthcoming(source=source)
 
+                self.review_manager.dataset.format_records_file()
+                self.review_manager.dataset.add_record_changes()
                 self.review_manager.dataset.add_changes(path=source.filename)
                 if not skip_commit:
                     self.review_manager.create_commit(msg="Run search")
 
+        if self.review_manager.in_ci_environment():
+            print("\n\n")
+
     def setup_custom_script(self) -> None:
         """Setup a custom search script"""
 
@@ -379,7 +401,7 @@ class Search(colrev.operation.Operation):
             filename=Path("data/search/custom_search.bib"),
             search_type=colrev.settings.SearchType.DB,
             search_parameters={},
-            load_conversion_package_endpoint={"endpoint": "colrev_built_in.bibtex"},
+            load_conversion_package_endpoint={"endpoint": "colrev.bibtex"},
             comment="",
         )
 
@@ -407,7 +429,6 @@ class GeneralOriginFeed:
         source_identifier: str,
         update_only: bool,
     ):
-
         self.source = search_source
         self.feed_file = search_source.get_corresponding_bib_file()
 
@@ -459,7 +480,6 @@ class GeneralOriginFeed:
 
         search_operation = self.review_manager.get_search_operation()
         if len(self.feed_records) > 0:
-
             self.feed_file.parents[0].mkdir(parents=True, exist_ok=True)
             self.review_manager.dataset.save_records_dict_to_file(
                 records=self.feed_records, save_path=self.feed_file
