@@ -70,6 +70,7 @@ class ReviewManager:
         high_level_operation: bool = False,
         navigate_to_home_dir: bool = True,
         exact_call: str = "",
+        skip_upgrade: bool = True,
     ) -> None:
         self.force_mode = force_mode
         """Force mode variable (bool)"""
@@ -131,6 +132,9 @@ class ReviewManager:
             self.environment_manager = self.get_environment_manager()
 
             self.p_printer = pprint.PrettyPrinter(indent=4, width=140, compact=False)
+            # run update before settings/data (which may require changes/fail without update)
+            if not skip_upgrade:
+                self.__check_update()
             self.settings = self.load_settings()
             self.dataset = colrev.dataset.Dataset(review_manager=self)
 
@@ -141,11 +145,7 @@ class ReviewManager:
             else:
                 raise exc
 
-        self.__check_update()
-
     def __check_update(self) -> None:
-        if not hasattr(self, "dataset"):
-            return
         # Once the following has run for all repositories,
         # it should only be called when the versions differ.
         # last_version, current_version = self.get_colrev_versions()
