@@ -645,6 +645,13 @@ def prep(
     default=False,
     help="Print statistics of records with colrev_status md_needs_manual_preparation",
 )
+@click.option(
+    "-l",
+    "--languages",
+    is_flag=True,
+    default=False,
+    help="Export spreadsheet to add missing language fields.",
+)
 @click.option(
     "-v",
     "--verbose",
@@ -660,7 +667,9 @@ def prep(
     help="Force mode",
 )
 @click.pass_context
-def prep_man(ctx: click.core.Context, stats: bool, verbose: bool, force: bool) -> None:
+def prep_man(
+    ctx: click.core.Context, stats: bool, languages: bool, verbose: bool, force: bool
+) -> None:
     """Prepare records manually"""
 
     try:
@@ -668,6 +677,9 @@ def prep_man(ctx: click.core.Context, stats: bool, verbose: bool, force: bool) -
             force_mode=force, verbose_mode=verbose, exact_call=EXACT_CALL
         )
         prep_man_operation = review_manager.get_prep_man_operation()
+        if languages:
+            prep_man_operation.prep_man_langs()
+            return
 
         if stats:
             prep_man_operation.prep_man_stats()
@@ -711,6 +723,12 @@ def __view_dedupe_details(dedupe_operation: colrev.ops.dedupe.Dedupe) -> None:
     "or non_duplicates_to_validate.xlsx or "
     "a dupes.txt file containing comma-separated ID tuples",
 )
+@click.option(
+    "-gid",
+    help="Merge records with identical global IDs (e.g., DOI)",
+    is_flag=True,
+    default=False,
+)
 @click.option("-v", "--view", is_flag=True, default=False, help="View dedupe info")
 @click.option(
     "-v",
@@ -732,6 +750,7 @@ def dedupe(
     merge: str,
     unmerge: str,
     fix_errors: bool,
+    gid: bool,
     view: bool,
     verbose: bool,
     force: bool,
@@ -757,7 +776,9 @@ def dedupe(
         if unmerge:
             dedupe_operation.unmerge_records(current_record_ids=unmerge.split(","))
             return
-
+        if gid:
+            dedupe_operation.merge_based_on_global_ids(apply=True)
+            return
         if fix_errors:
             dedupe_operation.fix_errors()
             print(
@@ -2130,7 +2151,7 @@ def settings(
                 "pre-commit",
                 "autoupdate",
                 "--repo",
-                "https://github.com/CoLRev-Ecosystem/colrev-hooks",
+                "https://github.com/CoLRev-Environment/colrev-hooks",
             ],
         ]
         for script_to_call in scripts_to_call:
@@ -2537,6 +2558,12 @@ def web(
 
 
 @main.command(hidden=True, help_priority=29)
+@click.option(
+    "--disable_auto",
+    is_flag=True,
+    default=False,
+    help="Disable automated upgrades",
+)
 @click.option(
     "-v",
     "--verbose",
@@ -2554,11 +2581,21 @@ def web(
 @click.pass_context
 def upgrade(
     ctx: click.core.Context,
+    disable_auto: bool,
     verbose: bool,
     force: bool,
 ) -> None:
     """Upgrade to the latest CoLRev project version."""
 
+    if disable_auto:
+        review_manager = colrev.review_manager.ReviewManager(
+            force_mode=True, verbose_mode=verbose, skip_upgrade=True
+        )
+
+        review_manager.settings.project.auto_upgrade = False
+        review_manager.save_settings()
+        review_manager.create_commit(msg="Disable auto-upgrade")
+        return
     review_manager = colrev.review_manager.ReviewManager(
         force_mode=True, verbose_mode=verbose
     )
